@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2016 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -35,6 +35,10 @@ private Q_SLOTS:
 
     void shouldParseQtLoggingLine_data();
     void shouldParseQtLoggingLine();
+
+    void shouldReadLoadKdeCategories_data();
+    void shouldReadLoadKdeCategories();
+
 };
 
 #endif // KDEBUGSETTINGUTILTEST_H
