@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2016 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -22,16 +22,17 @@
 #define CATEGORYTYPECOMBOBOX_H
 
 #include <QComboBox>
+#include "loggingcategory.h"
 
 class CategoryTypeComboBox : public QComboBox
 {
     Q_OBJECT
 public:
-    explicit CategoryTypeComboBox(QWidget *parent = Q_NULLPTR);
+    explicit CategoryTypeComboBox(bool customType, QWidget *parent = Q_NULLPTR);
     ~CategoryTypeComboBox();
 
-    QString type() const;
-    void setType(const QString &type);
+    LoggingCategory::LoggingType type() const;
+    void setType(LoggingCategory::LoggingType type);
 };
 
 #endif // CATEGORYTYPECOMBOBOX_H
