@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2016 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -59,7 +59,7 @@ void ConfigureCustomSettingDialog::setRule(const QString &rule)
     mCustomSettingWidget->setRule(rule);
 }
 
-QString ConfigureCustomSettingDialog::rule()
+QString ConfigureCustomSettingDialog::rule() const
 {
     return mCustomSettingWidget->rule();
 }
