@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2016 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -62,7 +62,7 @@ CustomDebugSettingsPage::CustomDebugSettingsPage(QWidget *parent)
     buttonLayout->addWidget(mEditRule);
     connect(mEditRule, &QAbstractButton::clicked, this, &CustomDebugSettingsPage::slotEditRule);
 
-    mRemoveRule = new QPushButton(i18n("Remove..."));;
+    mRemoveRule = new QPushButton(i18n("Remove..."));
     mRemoveRule->setObjectName(QStringLiteral("remove_rule"));
     buttonLayout->addWidget(mRemoveRule);
     buttonLayout->addStretch();
@@ -81,30 +81,69 @@ void CustomDebugSettingsPage::updateButtons()
     mRemoveRule->setEnabled(mListWidget->currentItem());
 }
 
-void CustomDebugSettingsPage::fillList(const Category::List &list)
+void CustomDebugSettingsPage::fillList(const LoggingCategory::List &list)
 {
-    Q_FOREACH (const Category &cat, list) {
-        QString rule;
-        rule = cat.logName;
-        if (!cat.type.isEmpty()) {
-            rule += QLatin1Char('.') + cat.type;
+    Q_FOREACH (const LoggingCategory &cat, list) {
+        QString ruleStr;
+        ruleStr = cat.logName;
+        switch (cat.loggingType) {
+        case LoggingCategory::Undefined:
+        case LoggingCategory::All:
+            break;
+        case LoggingCategory::Info:
+            ruleStr += QStringLiteral(".info");
+            break;
+        case LoggingCategory::Warning:
+            ruleStr += QStringLiteral(".warning");
+            break;
+        case LoggingCategory::Debug:
+            ruleStr += QStringLiteral(".debug");
+            break;
+        case LoggingCategory::Critical:
+            ruleStr += QStringLiteral(".critical");
+            break;
+        case LoggingCategory::Off:
+            break;
         }
         if (cat.enabled) {
-            rule += QStringLiteral("=true");
+            ruleStr += QStringLiteral("=true");
         } else {
-            rule += QStringLiteral("=false");
+            ruleStr += QStringLiteral("=false");
         }
-        new QListWidgetItem(rule, mListWidget);
+        new QListWidgetItem(ruleStr, mListWidget);
     }
 }
 
-Category::List CustomDebugSettingsPage::rules()
+LoggingCategory::List CustomDebugSettingsPage::rules()
 {
-    Category::List lst;
-    for (int i = 0; i < mListWidget->count(); ++i) {
-        const Category cat = KDebugSettingsUtil::parseLineLoggingQtCategory(mListWidget->item(i)->text());
+    LoggingCategory::List lst;
+    const int number(mListWidget->count());
+    for (int i = 0; i < number; ++i) {
+        const KDebugSettingsUtil::LineLoggingQtCategory cat = KDebugSettingsUtil::parseLineLoggingQtCategory(mListWidget->item(i)->text());
         if (cat.isValid()) {
-            lst.append(cat);
+            LoggingCategory tmp;
+            tmp.logName = cat.logName;
+            tmp.enabled = cat.enabled;
+            switch (cat.type) {
+            case KDebugSettingsUtil::LineLoggingQtCategory::Unknown:
+                break;
+            case KDebugSettingsUtil::LineLoggingQtCategory::Info:
+                tmp.loggingType = LoggingCategory::Info;
+                break;
+            case KDebugSettingsUtil::LineLoggingQtCategory::Warning:
+                tmp.loggingType = LoggingCategory::Warning;
+                break;
+            case KDebugSettingsUtil::LineLoggingQtCategory::Debug:
+                tmp.loggingType = LoggingCategory::Debug;
+                break;
+            case KDebugSettingsUtil::LineLoggingQtCategory::Critical:
+                tmp.loggingType = LoggingCategory::Critical;
+                break;
+            case KDebugSettingsUtil::LineLoggingQtCategory::All:
+                tmp.loggingType = LoggingCategory::All;
+                break;
+            }
+            lst.append(tmp);
         }
     }
     return lst;
@@ -143,7 +182,8 @@ void CustomDebugSettingsPage::slotAddRule()
         const QString ruleStr = dlg->rule();
         if (!ruleStr.isEmpty()) {
             bool alreadyAdded = false;
-            for (int i = 0; i < mListWidget->count(); ++i) {
+            const int number(mListWidget->count());
+            for (int i = 0; i < number; ++i) {
                 if (ruleStr == mListWidget->item(i)->text()) {
                     alreadyAdded = true;
                     break;
